Description Details Author(s) References
Testing high-dimensional parameters under generalized linear models (GLMs) with high-dimensional nuisance parameters is largely untouched. Most existing tests are powerful only against certain alternatives and may yield incorrect Type 1 error rates under high-dimensional nuisance parameters situations. This package provides a new test called the adaptive interaction sum of powered score (aiSPU) test based on the truncated Lasso penalty and an adaptive testing idea, which can maintain high statistical power and correct Type I error rates across a wide range of alternatives. Some related methods have been implemented in this package as well.
This package provides a new test called the adaptive interaction sum of powered score (aiSPU) test based on the truncated Lasso penalty and an adaptive testing idea. Some related methods have been implemented in this package as well.
Chong Wu and Wei Pan
Maintainer: Chong Wu <cwu3@fsu.edu>
Wu, C., Xu, G., Shen, X., & Pan, W. (2020+). A Regularization-Based Adaptive Test for High-Dimensional Generalized Linear Models, Submitted.
Zhang, X., & Cheng, G. (2017). Simultaneous inference for high-dimensional linear models. Journal of the American Statistical Association, 112(518), 757-768.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.